package pt.up.dcc.vcandroid;

import android.content.Context;
import android.hardware.Camera;
import android.hardware.Camera.Size;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

public class CameraPreview extends SurfaceView implements SurfaceHolder.Callback {
	private static final String TAG = "CameraPreview";
	private SurfaceHolder mHolder;
	private Camera mCamera;
	private PreviewAnalyzer prevAn;

	public CameraPreview(Context context, Camera camera) {
		super(context);
		setCamera(camera);
	}


	public void setCamera(Camera camera) {
		mCamera = camera;
		// Install a SurfaceHolder.Callback so we get notified when the
		// underlying surface is created and destroyed.
		mHolder = getHolder();
		mHolder.addCallback(this);
	}

	

	public void surfaceCreated(SurfaceHolder holder) {
		// The Surface has been created, now tell the camera where to draw the preview.
		try {
			// Attach Preview Analyzer to analize frames
			prevAn = new PreviewAnalyzer(mHolder);
			Camera.Parameters p = mCamera.getParameters();
			Camera.Size selectedSize = null;
			for (Camera.Size s : p.getSupportedPreviewSizes()) {
				selectedSize = s;
			}

			p.setPreviewSize(selectedSize.width, selectedSize.height);
			prevAn.setPreviewSize(selectedSize);
			mCamera.setPreviewCallback(prevAn);
			mCamera.setParameters(p);
			mCamera.startPreview();
		} catch (Exception e) {
			Log.d(TAG, "Error setting camera preview: " + e.getMessage());
		}
	}

	public void surfaceDestroyed(SurfaceHolder holder) {
		// empty.
	}

	public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
		// empty.
	}

	public void setCameraSize(Size s) {
		mCamera.stopPreview();
		Camera.Parameters p = mCamera.getParameters();
		p.setPreviewSize(s.width, s.height);
		mCamera.setParameters(p);
		mCamera.setPreviewCallback(prevAn);
		prevAn.setPreviewSize(s);
		mCamera.startPreview();
	}

}
